This project was created as per insturctions during the interview proccess with Scientific Games -Cedar Falls. It aims to solve the following problem:

Problem Statement:

Given a list of people with their birth and end years (all between 1900 and 2000), find the year with the most number of people alive.


